@@ -729,6 +729,18 @@ sub visibleFields {
 	return wantarray ? @visibleFieldList : \@visibleFieldList;
 }
 
+#------------------------------------------------------------------------------
+sub webcontrol {
+	my $self = shift;
+	my $field = shift;
+
+	if (exists $self->fieldlist->{$field}) {
+		return $self->fieldlist->{$field}->{webcontrol};
+	} else {
+		return;
+	}
+}
+
 #-----------------------------------------------------------------------------
 sub where {
 	my $self = shift;
@@ -1226,6 +1238,12 @@ array ref. list of fields with their attributes
 
 		handle	=> reference whose referrent will contain whatever value is set into db.  Useful for later use in cgi.
 
+	webcontrol	=> type of input displayed to browser.  Defaults to text input field.
+		
+		type	=> select, checkbox, text.  Text is the default.
+
+		values	=> arrayref, or hashref.  If arrayref, both displayed value and value will be the same.  If hashref, key will be label, value will be value.  
+
 
 =head3 updatedefaults 
 
@@ -1366,6 +1384,14 @@ Returns array or arrayref of labels for non-hidden fields.
 
 Returns array or arrayref of field names that are not hidden
 
+=head2 webcontrol (field)
+
+Returns webcontrol hashref for field.
+
+=head3 field
+
+Name of field.
+
 =head2 where($sql, binds)
 	
 Gets or sets the where clause.  If called with a single argument, argument is assumed to be sql string for the where clause.  If called with multiple args, first element is sql string, everything else is bind values.  When called without arguments, it returns whatever's been set.  This could be a single string, or an array ref, depending on how it was last called.
